
// (c) COPYRIGHT URI/MIT 1996,1997
// Please read the full copyright statement in the file COPYRIGHT.
//
// Authors:
//	reza		Reza Nekovei (reza@intcomm.net)

// This is the main CGI program which extracts DAS class attributes from a
// DSP image file. In addition, the attributes from an external file (if 
// exist, with the same name as the DSP image file and extension of .das at the 
// end) are extracted and added to the in-memory atrribute table before it is 
// sent over the network to the client side. 
//
// ReZa 8/22/96
//

#include "config_dsp.h"

static char *rcsid not_used = "$Id: dsp_das.cc,v 1.9 2003/02/10 21:19:02 jimg Exp $";

#include <iostream>
#include <string>

#include "DAS.h"
#include "cgi_util.h"
#include "DODSFilter.h"

const string cgi_version = DODS_SERVER_VERSION;
extern bool read_attributes(DAS &das, const string &filename, string *error);

int 
main(int argc, char *argv[])
{
    DAS das;
    DODSFilter df(argc, argv);

    if (!df.OK()) {
	df.print_usage();
	return 1;
    }

    if (df.version()) {
	df.set_cgi_version(cgi_version);
	df.send_version_info();
	return 0;
    }

    try {
      // Read the attributes in memory and forward all the errors to client
      // program
      string errMsg;
      if (!read_attributes(das, df.get_dataset_name(), &errMsg)) {
	Error e(no_such_file, errMsg);
	set_mime_text(cout, dods_error);
	e.print(cout);
	return 1;
      }

      df.read_ancillary_das(das);

      df.send_das(das);
    }
    catch(Error &e) {
      set_mime_text(cout, dods_error, df.get_cgi_version());
      e.print(cout);
      return 1;
    }

    return 0;
}

// $Log: dsp_das.cc,v $
// Revision 1.9  2003/02/10 21:19:02  jimg
// Merged changes from 3.2.4.
//
// Revision 1.8.4.1  2002/04/05 14:48:18  jimg
// I added the stuff needed to send the new version string info back to
// clients. See bug 205. Note that I also fixed this for dsp_das.cc but
// hosed the CVS log for that file.
//
// Revision 1.8  2000/10/09 21:25:00  jimg
// Moved CVS Log entries to the end of each file.
// Changed the definition of the read method to match the dap library.
// Added exceptions to the read methods.
// Added code to catch exceptions in dsp_das, _dds and _dods.
//
// Revision 1.7  1999/04/30 21:32:48  jimg
// Merged no-gnu and release-2-17
//
// Revision 1.6.8.1  1999/02/10 06:28:59  brent
// convert to Standard C++ strings -- b^2
//
// Revision 1.6  1998/03/20 00:29:51  jimg
// Changed calls to the set_mime_*() to match the new parameters
//
// Revision 1.5  1997/12/31 08:16:18  jimg
// Fixed read_attributes() function name (was read_variables).
//
// Revision 1.4  1997/07/15 17:53:38  jimg
// merged release-2-1-4 changes
//
// Revision 1.3.2.1  1997/07/15 00:49:51  jimg
// Fixed as per Dan's changes for version 2.14; changed the DAS and DDS objects
// so that the are pointers and not global static objects.
//
// Revision 1.3  1997/03/10 05:41:53  reza
// Added error objects to the code and updated for release 2.12.
// Now the data is sent gzip compressed.
//
// Revision 1.2  1996/11/15 18:22:29  jimg
// Fixed copyright statement.
// Added include of config header
//
// Revision 1.1  1996/09/18 22:42:26  reza
//  First release of DODS-DSP servers.
//
